@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Draw fretboard chord diagrams
 
-our $VERSION = '0.0802';
+our $VERSION = '0.0900';
 
 use Moo;
 use strictures 2;
@@ -137,6 +137,7 @@ sub draw {
 
     my $WHITE = 'white';
     my $BLACK = 'black';
+    my $GRAY  = 'gray';
     my $GRID  = $self->grid;
     my $SPACE = $self->size;
 
@@ -194,6 +195,35 @@ sub draw {
                 aa    => 1,
             );
         }
+
+        if (
+            ( $self->position + $fret == 3 )
+            ||
+            ( $self->position + $fret == 5 )
+            ||
+            ( $self->position + $fret == 7 )
+            ||
+            ( $self->position + $fret == 9 )
+            ||
+            ( $self->position + $fret == 12 )
+            ||
+            ( $self->position + $fret == 15 )
+            ||
+            ( $self->position + $fret == 17 )
+            ||
+            ( $self->position + $fret == 19 )
+            ||
+            ( $self->position + $fret == 21 )
+            ||
+            ( $self->position + $fret == 24 )
+        ) {
+            $i->circle(
+                color => $GRAY,
+                r     => $SPACE / 8,
+                x     => $SPACE * $self->strings / 2 + $SPACE / 2,
+                y     => $SPACE + $fret * $SPACE + $SPACE / 2,
+            ) if ( $SPACE + $fret * $SPACE + $SPACE / 2 ) < ( $SPACE * $self->frets );
+        }
     }
 
     # Draw the note/mute markers
@@ -270,6 +300,7 @@ sub _draw_horiz {
 
     my $WHITE = 'white';
     my $BLACK = 'black';
+    my $GRAY  = 'gray';
     my $GRID  = $self->grid;
     my $SPACE = $self->size;
 
@@ -327,6 +358,35 @@ sub _draw_horiz {
                 aa    => 1,
             );
         }
+
+        if (
+            ( $self->position + $fret == 3 )
+            ||
+            ( $self->position + $fret == 5 )
+            ||
+            ( $self->position + $fret == 7 )
+            ||
+            ( $self->position + $fret == 9 )
+            ||
+            ( $self->position + $fret == 12 )
+            ||
+            ( $self->position + $fret == 15 )
+            ||
+            ( $self->position + $fret == 17 )
+            ||
+            ( $self->position + $fret == 19 )
+            ||
+            ( $self->position + $fret == 21 )
+            ||
+            ( $self->position + $fret == 24 )
+        ) {
+            $i->circle(
+                color => $GRAY,
+                r     => $SPACE / 8,
+                y     => $SPACE * $self->strings / 2 + $SPACE / 2,
+                x     => $SPACE + $fret * $SPACE + $SPACE / 2,
+            ) if ( $SPACE + $fret * $SPACE + $SPACE / 2 ) < ( $SPACE * $self->frets );
+        }
     }
 
     # Draw the note/mute markers
@@ -424,7 +484,7 @@ Music::FretboardDiagram - Draw fretboard chord diagrams
 
 =head1 VERSION
 
-version 0.0802
+version 0.0900
 
 =head1 SYNOPSIS
 
